aboutsummaryrefslogtreecommitdiff
path: root/common/unzip.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'common/unzip.cpp')
-rw-r--r--common/unzip.cpp13
1 files changed, 5 insertions, 8 deletions
diff --git a/common/unzip.cpp b/common/unzip.cpp
index d56893f3cd..91f352f40a 100644
--- a/common/unzip.cpp
+++ b/common/unzip.cpp
@@ -17,9 +17,6 @@
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * $URL$
- * $Id$
*/
/* unzip.c -- IO on .zip files using zlib
@@ -352,7 +349,7 @@ typedef struct {
z_stream stream; /* zLib stream structure for inflate */
uLong pos_in_zipfile; /* position in byte on the zipfile, for fseek*/
- uLong stream_initialised; /* flag set if stream structure is initialised*/
+ uLong stream_initialized; /* flag set if stream structure is initialized*/
uLong offset_local_extrafield;/* offset of the local extra field */
uInt size_local_extrafield;/* size of the local extra field */
@@ -1076,7 +1073,7 @@ int unzOpenCurrentFile (unzFile file) {
return UNZ_INTERNALERROR;
}
- pfile_in_zip_read_info->stream_initialised=0;
+ pfile_in_zip_read_info->stream_initialized=0;
if ((s->cur_file_info.compression_method!=0) &&
(s->cur_file_info.compression_method!=Z_DEFLATED))
@@ -1099,7 +1096,7 @@ int unzOpenCurrentFile (unzFile file) {
err=inflateInit2(&pfile_in_zip_read_info->stream, -MAX_WBITS);
if (err == Z_OK)
- pfile_in_zip_read_info->stream_initialised = 1;
+ pfile_in_zip_read_info->stream_initialized = 1;
/* windowBits is passed < 0 to tell that there is no zlib header.
* Note that in this case inflate *requires* an extra "dummy" byte
* after the compressed stream in order to complete decompression and
@@ -1368,7 +1365,7 @@ int unzCloseCurrentFile(unzFile file) {
if (pfile_in_zip_read_info->crc32_data != pfile_in_zip_read_info->crc32_wait)
err=UNZ_CRCERROR;
}
- if (pfile_in_zip_read_info->stream_initialised)
+ if (pfile_in_zip_read_info->stream_initialized)
inflateEnd(&pfile_in_zip_read_info->stream);
#endif
@@ -1376,7 +1373,7 @@ int unzCloseCurrentFile(unzFile file) {
free(pfile_in_zip_read_info->read_buffer);
pfile_in_zip_read_info->read_buffer = NULL;
- pfile_in_zip_read_info->stream_initialised = 0;
+ pfile_in_zip_read_info->stream_initialized = 0;
free(pfile_in_zip_read_info);
s->pfile_in_zip_read=NULL;